@@ -13,7 +13,6 @@
 
 #include <KConfig>
 #include <KConfigGroup>
-#include <KIO/JobUiDelegate>
 #include <KIO/PreviewJob>
 #include <KIconLoader>
 #include <KJobWidgets>
@@ -28,12 +27,14 @@
 #endif
 
 #include <QApplication>
+#include <QElapsedTimer>
 #include <QFileInfo>
-#include <QIcon>
 #include <QPainter>
 #include <QPluginLoader>
-#include <QElapsedTimer>
 #include <QTimer>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 // #define KFILEITEMMODELROLESUPDATER_DEBUG
 
@@ -107,7 +108,7 @@ KFileItemModelRolesUpdater::KFileItemModelRolesUpdater(KFileItemModel* model, QO
     // Use a timer to prevent that each call of slotItemsChanged() results in a synchronous
     // resolving of the roles. Postpone the resolving until no update has been done for 100 ms.
     m_recentlyChangedItemsTimer = new QTimer(this);
-    m_recentlyChangedItemsTimer->setInterval(100);
+    m_recentlyChangedItemsTimer->setInterval(100ms);
     m_recentlyChangedItemsTimer->setSingleShot(true);
     connect(m_recentlyChangedItemsTimer, &QTimer::timeout, this, &KFileItemModelRolesUpdater::resolveRecentlyChangedItems);
 
@@ -455,7 +456,7 @@ void KFileItemModelRolesUpdater::slotItemsRemoved(const KItemRangeList& itemRang
     }
 }
 
-void KFileItemModelRolesUpdater::slotItemsMoved(const KItemRange& itemRange, const QList<int> &movedToIndexes)
+void KFileItemModelRolesUpdater::slotItemsMoved(KItemRange itemRange, const QList<int> &movedToIndexes)
 {
     Q_UNUSED(itemRange)
     Q_UNUSED(movedToIndexes)
@@ -1350,7 +1351,9 @@ QHash<QByteArray, QVariant> KFileItemModelRolesUpdater::rolesData(const KFileIte
     for (KOverlayIconPlugin *it : qAsConst(m_overlayIconsPlugin)) {
         overlays.append(it->getOverlays(item.url()));
     }
-    data.insert("iconOverlays", overlays);
+    if (!overlays.isEmpty()) {
+        data.insert("iconOverlays", overlays);
+    }
 
 #if HAVE_BALOO
     if (m_balooFileMonitor) {
