@@ -399,8 +399,6 @@ protected:
     virtual void updateFont();
     virtual void updatePalette();
 
-    KItemListSizeHintResolver* m_sizeHintResolver;
-
 protected Q_SLOTS:
     virtual void slotItemsInserted(const KItemRangeList& itemRanges);
     virtual void slotItemsRemoved(const KItemRangeList& itemRanges);
@@ -432,7 +430,7 @@ private Q_SLOTS:
                                       qreal currentWidth,
                                       qreal previousWidth);
 
-    void slotLeadingPaddingChanged(qreal width);
+    void slotSidePaddingChanged(qreal width);
 
     /**
      * Is invoked if a column has been moved by the user. Applies
@@ -774,6 +772,8 @@ private:
 
     QList<QVariantAnimation*> m_rubberBandAnimations;
 
+    KItemListSizeHintResolver* m_sizeHintResolver;
+
     friend class KItemListContainer; // Accesses scrollBarRequired()
     friend class KItemListHeader;    // Accesses m_headerWidget
     friend class KItemListController;
